@@ -49,6 +49,8 @@ struct nonlinear {
   double eta_0;      /** for HMcode: halo bloating parameter */
   double z_infinity; /** for HMcode: z value at which Dark Energy correction is evaluated needs to be at early times (default */
 
+  short has_pk_eq;  /**< flag: in case wa_fld is defined and non-zero, should we use the pk_eq method? */
+
   //@}
 
   /** @name - information on number of modes and pairs of initial conditions */
@@ -169,8 +171,6 @@ struct nonlinear {
 
   //@{
 
-  short has_pk_eq;               /**< flag: will we use the pk_eq method? */
-
   int index_pk_eq_w;                /**< index of w in table pk_eq_w_and_Omega */
   int index_pk_eq_Omega_m;          /**< index of Omega_m in table pk_eq_w_and_Omega */
   int pk_eq_size;                   /**< number of indices in table pk_eq_w_and_Omega */
