@@ -709,12 +709,12 @@ extern "C" {
                    struct perturbs * ppt
                    );
 
-  int perturb_indices_of_perturbs(
-                                  struct precision * ppr,
-                                  struct background * pba,
-                                  struct thermo * pth,
-                                  struct perturbs * ppt
-                                  );
+  int perturb_indices(
+                      struct precision * ppr,
+                      struct background * pba,
+                      struct thermo * pth,
+                      struct perturbs * ppt
+                      );
 
   int perturb_timesampling_for_sources(
                                        struct precision * ppr,
